package com.ruoyi.base.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.base.mapper.RobotOpsScreenThemeConfigMapper;
import com.ruoyi.base.domain.RobotOpsScreenThemeConfig;
import com.ruoyi.base.service.IRobotOpsScreenThemeConfigService;

/**
 * 展示主题配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-05-14
 */
@Service
public class RobotOpsScreenThemeConfigServiceImpl implements IRobotOpsScreenThemeConfigService 
{
    @Autowired
    private RobotOpsScreenThemeConfigMapper robotOpsScreenThemeConfigMapper;

    /**
     * 查询展示主题配置
     *
     * @param id 展示主题配置主键
     * @return 展示主题配置
     */
    @Override
    public RobotOpsScreenThemeConfig selectRobotOpsScreenThemeConfigById(Long id)
    {
        return robotOpsScreenThemeConfigMapper.selectRobotOpsScreenThemeConfigById(id);
    }

    /**
     * 根据配置标识查询展示主题配置
     *
     * @param configKey 配置标识
     * @return 展示主题配置
     */
    @Override
    public RobotOpsScreenThemeConfig selectRobotOpsScreenThemeConfigByConfigKey(String configKey)
    {
        return robotOpsScreenThemeConfigMapper.selectRobotOpsScreenThemeConfigByConfigKey(configKey);
    }

    /**
     * 查询展示主题配置列表
     * 
     * @param robotOpsScreenThemeConfig 展示主题配置
     * @return 展示主题配置
     */
    @Override
    public List<RobotOpsScreenThemeConfig> selectRobotOpsScreenThemeConfigList(RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        return robotOpsScreenThemeConfigMapper.selectRobotOpsScreenThemeConfigList(robotOpsScreenThemeConfig);
    }

    /**
     * 新增展示主题配置
     * 
     * @param robotOpsScreenThemeConfig 展示主题配置
     * @return 结果
     */
    @Override
    public int insertRobotOpsScreenThemeConfig(RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        robotOpsScreenThemeConfig.setCreateTime(DateUtils.getNowDate());
        return robotOpsScreenThemeConfigMapper.insertRobotOpsScreenThemeConfig(robotOpsScreenThemeConfig);
    }

    /**
     * 修改展示主题配置
     * 
     * @param robotOpsScreenThemeConfig 展示主题配置
     * @return 结果
     */
    @Override
    public int updateRobotOpsScreenThemeConfig(RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        robotOpsScreenThemeConfig.setUpdateTime(DateUtils.getNowDate());
        return robotOpsScreenThemeConfigMapper.updateRobotOpsScreenThemeConfig(robotOpsScreenThemeConfig);
    }

    /**
     * 批量删除展示主题配置
     * 
     * @param ids 需要删除的展示主题配置主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsScreenThemeConfigByIds(Long[] ids)
    {
        return robotOpsScreenThemeConfigMapper.deleteRobotOpsScreenThemeConfigByIds(ids);
    }

    /**
     * 删除展示主题配置信息
     * 
     * @param id 展示主题配置主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsScreenThemeConfigById(Long id)
    {
        return robotOpsScreenThemeConfigMapper.deleteRobotOpsScreenThemeConfigById(id);
    }
}
