package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.RobotOpsScreenThemeConfig;
import com.ruoyi.base.service.IRobotOpsScreenThemeConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 展示主题配置Controller
 *
 * @author ruoyi
 * @date 2026-05-14
 */
@RestController
@RequestMapping("/base/opsScreenThemeConfig")
public class RobotOpsScreenThemeConfigController extends BaseController
{
    @Autowired
    private IRobotOpsScreenThemeConfigService robotOpsScreenThemeConfigService;

    /**
     * 查询展示主题配置列表
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        startPage();
        List<RobotOpsScreenThemeConfig> list = robotOpsScreenThemeConfigService.selectRobotOpsScreenThemeConfigList(robotOpsScreenThemeConfig);
        return getDataTable(list);
    }

    /**
     * 导出展示主题配置列表
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:export')")
    @Log(title = "展示主题配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        List<RobotOpsScreenThemeConfig> list = robotOpsScreenThemeConfigService.selectRobotOpsScreenThemeConfigList(robotOpsScreenThemeConfig);
        ExcelUtil<RobotOpsScreenThemeConfig> util = new ExcelUtil<RobotOpsScreenThemeConfig>(RobotOpsScreenThemeConfig.class);
        util.exportExcel(response, list, "展示主题配置数据");
    }

    /**
     * 获取展示主题配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(robotOpsScreenThemeConfigService.selectRobotOpsScreenThemeConfigById(id));
    }

    /**
     * 新增展示主题配置
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:add')")
    @Log(title = "展示主题配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        return toAjax(robotOpsScreenThemeConfigService.insertRobotOpsScreenThemeConfig(robotOpsScreenThemeConfig));
    }

    /**
     * 修改展示主题配置
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:edit')")
    @Log(title = "展示主题配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RobotOpsScreenThemeConfig robotOpsScreenThemeConfig)
    {
        return toAjax(robotOpsScreenThemeConfigService.updateRobotOpsScreenThemeConfig(robotOpsScreenThemeConfig));
    }

    /**
     * 删除展示主题配置
     */
    @PreAuthorize("@ss.hasPermi('base:opsScreenThemeConfig:remove')")
    @Log(title = "展示主题配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(robotOpsScreenThemeConfigService.deleteRobotOpsScreenThemeConfigByIds(ids));
    }
}
